@@ -1,15 +1,14 @@
+from dataclasses import dataclass, field
 from typing import Any, Callable, List, Optional, Dict, Union
 
-import tensorflow as tf  # type: ignore
 import numpy as np
 import numpy.typing as npt
-from dataclasses import dataclass, field
+import tensorflow as tf  # type: ignore
 
-from code_loader.contract.decoder_classes import LeapImage, LeapText, LeapNumeric, LeapGraph, LeapHorizontalBar, \
+from code_loader.contract.visualizer_classes import  LeapImage, LeapText, LeapNumeric, LeapGraph, LeapHorizontalBar, \
     LeapTextMask, LeapImageMask
 from code_loader.contract.enums import DataStateType, DatasetMetadataType, \
-    DataStateEnum, LeapDataType
-from code_loader.contract.responsedataclasses import PredictionTypeInstance
+    DataStateEnum, LeapDataType, Metric
 
 
 @dataclass
@@ -20,14 +19,25 @@ class PreprocessResponse:
 
 SectionCallableInterface = Callable[[int, PreprocessResponse], npt.NDArray[np.float32]]
 
+MetadataSectionCallableInterface = Union[
+    Callable[[int, PreprocessResponse], int],
+    Callable[[int, PreprocessResponse], str],
+    Callable[[int, PreprocessResponse], bool],
+    Callable[[int, PreprocessResponse], float]
+]
+
 
 @dataclass
 class PreprocessHandler:
     function: Callable[[], List[PreprocessResponse]]
     data_length: Dict[DataStateType, int] = field(default_factory=dict)
 
+@dataclass
+class UnlabeledDataPreprocessHandler:
+    function: Callable[[], PreprocessResponse]
+    data_length: int = 0
 
-DecoderCallableInterface = Union[
+VisualizerCallableInterface = Union[
     Callable[..., LeapImage],
     Callable[..., LeapNumeric],
     Callable[..., LeapText],
@@ -37,23 +47,22 @@ DecoderCallableInterface = Union[
     Callable[..., LeapTextMask],
 ]
 
-DecoderCallableReturnType = Union[LeapImage, LeapNumeric, LeapText,
-                                  LeapGraph, LeapHorizontalBar, LeapImageMask, LeapTextMask]
+VisualizerCallableReturnType = Union[LeapImage, LeapNumeric, LeapText,
+                                     LeapGraph, LeapHorizontalBar, LeapImageMask, LeapTextMask]
 
-
-CustomLossCallableInterface = Callable[[tf.Tensor, tf.Tensor], tf.Tensor]
+CustomCallableInterface = Callable[[tf.Tensor, tf.Tensor], tf.Tensor]
 
 
 @dataclass
 class CustomLossHandler:
     name: str
-    function: CustomLossCallableInterface
+    function: CustomCallableInterface
 
 
 @dataclass
-class DecoderHandler:
+class VisualizerHandler:
     name: str
-    function: DecoderCallableInterface
+    function: VisualizerCallableInterface
     type: LeapDataType
     arg_names: List[str]
     heatmap_function: Optional[Callable[..., npt.NDArray[np.float32]]] = None
@@ -76,25 +85,36 @@ class GroundTruthHandler(DatasetBaseHandler):
 
 
 @dataclass
-class MetadataHandler(DatasetBaseHandler):
+class MetadataHandler:
+    name: str
+    function: MetadataSectionCallableInterface
     type: DatasetMetadataType
 
 
+@dataclass
+class PredictionTypeHandler:
+    name: str
+    labels: List[str]
+    metrics: List[Metric]
+    custom_metrics: Optional[List[CustomCallableInterface]] = None
+
+
 @dataclass
 class DatasetIntegrationSetup:
     preprocess: Optional[PreprocessHandler] = None
-    decoders: List[DecoderHandler] = field(default_factory=list)
+    unlabeled_data_preprocess: Optional[UnlabeledDataPreprocessHandler] = None
+    visualizers: List[VisualizerHandler] = field(default_factory=list)
     inputs: List[InputHandler] = field(default_factory=list)
     ground_truths: List[GroundTruthHandler] = field(default_factory=list)
     metadata: List[MetadataHandler] = field(default_factory=list)
-    prediction_types: List[PredictionTypeInstance] = field(default_factory=list)
+    prediction_types: List[PredictionTypeHandler] = field(default_factory=list)
     custom_loss_handlers: List[CustomLossHandler] = field(default_factory=list)
 
 
 @dataclass
 class DatasetSample:
     inputs: Dict[str, npt.NDArray[np.float32]]
-    gt: Dict[str, npt.NDArray[np.float32]]
-    metadata: Dict[str, npt.NDArray[np.float32]]
+    gt: Optional[Dict[str, npt.NDArray[np.float32]]]
+    metadata: Dict[str, Union[str, int, bool, float]]
     index: int
     state: DataStateEnum
